@@ -5,7 +5,7 @@ import hashlib
 
 from ..libs.segwit import encode
 from ..libs.ed25519 import (encodepoint, decodepoint, decodeint, scalarmultbase, edwards_add)
-from .utils import prune_intermediate_scalar, get_bytes
+from .utils import prune_intermediate_scalar, get_bytes, bad_seed_checker
 
 
 # Constant values
@@ -66,9 +66,8 @@ def get_expand_xprivate_key(xprivate_key):
     i = hmac.HMAC(b"Expand", get_bytes(xprivate_key),
                   digestmod=hashlib.sha512).hexdigest()
     il, ir = i[:64], i[64:]
-    parse_ir = str(ir)
-    if not parse_ir:
-        raise ValueError("bad seed, resulting in invalid key!")
+    bad_seed_checker(ir, True)
+
     expand_xprivate_key = xprivate_key[:64] + ir
     return expand_xprivate_key
 
@@ -169,10 +168,7 @@ def get_child_xprivate_key(xprivate_key, indexes=None, path=None):
                                 b"N" + xpublic_bytes[:32] + index_bytes,
                                 digestmod=hashlib.sha512).digest())
         il, ir = i[:32], i[32:]
-
-        parse_il = int.from_bytes(il, "big")
-        if parse_il == 0:
-            raise ValueError("bad seed, resulting in invalid key!")
+        bad_seed_checker(il)
 
         i = prune_intermediate_scalar(il)[:32] + ir
 
@@ -228,10 +224,7 @@ def get_child_xpublic_key(xpublic_key, indexes=None, path=None):
                                 digestmod=hashlib.sha512).digest())
 
         il, ir = i[:32], i[32:]
-
-        parse_il = int.from_bytes(il, "big")
-        if parse_il == 0:
-            raise ValueError("bad seed, resulting in invalid key!")
+        bad_seed_checker(il)
 
         f = bytes(prune_intermediate_scalar(il))
         scalar = decodeint(f)
@@ -343,3 +336,33 @@ def get_address(program, network="solonet"):
         return encode("sm", 0, get_bytes(program[4:]))
     elif network == "testnet":
         return encode("tm", 0, get_bytes(program[4:]))
+
+
+def get_vapor_address(program, network="solonet"):
+    """
+    Get bytom vapor address from program.
+
+    :param program: Bytom control program.
+    :type program: str.
+    :param network: Bytom network, default to solonet.
+    :type network: str.
+    :return: str -- Bytom vapor address.
+
+    >>> from pybytom.wallet.tools import get_vapor_address
+    >>> get_vapor_address("00142cda4f99ea8112e6fa61cdd26157ed6dc408332a", "mainnet")
+    "vp1q9ndylx02syfwd7npehfxz4lddhzqsve2za23ag"
+    """
+
+    if not isinstance(program, str):
+        raise TypeError("program must be string format")
+    if not isinstance(network, str):
+        raise TypeError("network must be string format")
+
+    if network not in "mainnet/solonet/testnet".split("/"):
+        raise ValueError("invalid network option, choose only mainnet, solonet and testnet network")
+    elif network == "mainnet":
+        return encode("vp", 0, get_bytes(program[4:]))
+    elif network == "solonet":
+        return encode("sp", 0, get_bytes(program[4:]))
+    elif network == "testnet":
+        return encode("tp", 0, get_bytes(program[4:]))
